import { ReducersMapObject } from 'redux';
import SagaWatcher from '@overflow/commons/redux/saga/SagaWatcher';

import signInReducer from '@overflow/member/redux/reducer/signIn';
import signUpReducer from '@overflow/member/redux/reducer/signUp';
import modifyMemberReducer from '@overflow/member/redux/reducer/modify';
import readMemberReducer from '@overflow/member/redux/reducer/read';

import readAllProbeReducer from '@overflow/probe/redux/reducer/readAllByDomain';
import readProbeReducer from '@overflow/probe/redux/reducer/read';
import hostReadByProbeReducer from '@overflow/probe/redux/reducer/host_read_by_probe';
import modifyProbeReducer from '@overflow/probe/redux/reducer/modify';

import readNoAuthProbeReducer from '@overflow/noauthprobe/redux/reducer/read_all_by_domain';
import noauthAcceptReducer from '@overflow/noauthprobe/redux/reducer/accept';
import noauthDenyReducer from '@overflow/noauthprobe/redux/reducer/deny';

import readAllTargetByProbeReducer from '@overflow/target/redux/reducer/readAllByProbe';
import readAllTargetByDomainReducer from '@overflow/target/redux/reducer/read_all_by_domain';

import readTargetReducer from '@overflow/target/redux/reducer/read';

import sensorReadAllByTargetReducer from '@overflow/sensor/redux/reducer/read_all_by_target';
import sensorReadAllByDomainReducer from '@overflow/sensor/redux/reducer/read_all_by_domain';
import SensorReadReducer from '@overflow/sensor/redux/reducer/read';
import SensorItemReadAllBySensorReducer from '@overflow/sensor/redux/reducer/item_read_all_by_sensor';
import readAllTargetByInfraReducer from '@overflow/sensor/redux/reducer/read_all_by_infra';
import SensorRegistSensorConfigReducer from '@overflow/sensor/redux/reducer/regist_sensor_config';

import readMachineReducer from '@overflow/infra/redux/reducer/machine_read';
import readHostReducer from '@overflow/infra/redux/reducer/host_read';
import readOSReducer from '@overflow/infra/redux/reducer/os_read';
import readServiceReducer from '@overflow/infra/redux/reducer/service_read';
import InfraReadServiceReducer from '@overflow/infra/redux/reducer/read';

import CrawlerReadAllByTargetReducer from '@overflow/meta/redux/reducer/crawler_read_all_by_target';
import CrawlerAuthInputsReducer from '@overflow/meta/redux/reducer/crawler_auth_inputs';

import MetaSensorItemReadAllReducer from '@overflow/meta/redux/reducer/sensor_item_read_all';
import MetaSensorItemTypeReadAllReducer from '@overflow/meta/redux/reducer/sensor_item_type_read_all';

import DiscoveryInfraTargetRegistAllReducer from '@overflow/discovery/redux/reducer/infra_target_regist_all';

import HistoryReadAllByProbeReducer from '@overflow/history/redux/reducer/read_all_by_probe';
import HistoryReadAllByProbeAndTypeReducer from '@overflow/history/redux/reducer/read_all_by_probe_and_type';
import HistoryTypeReadAllReducer from '@overflow/meta/redux/reducer/history_type_read_all';
import NotificationReadAllUnconfirmedReducer from '@overflow/notification/redux/reducer/read_all_unconfirmed';


import AsyncRequest from '@overflow/app/redux/saga/AsyncRequest';

// Container Configuration
export interface ContainerConfig {
  placeholderID: string;
}
const containerConfig: ContainerConfig = {
  placeholderID: 'appContainer',
};

// RPC Server Configuration
export interface RPCConfig {
  url: string;
}
const rpcConfig: RPCConfig = {
  url: 'ws://127.0.0.1:18081/rpc',
};

// Redux Configuration
export interface ReduxConfig {
  state: ReduxState;
  reducerMaps: ReducersMapObject[];
  sagaWatchers: Class<SagaWatcher>[];
}
export interface ReduxState {

}
const reduxState: ReduxState = {};



const reduxConfig: ReduxConfig = {
  state: reduxState,
  reducerMaps: [
    signInReducer,
    readMemberReducer,
    modifyMemberReducer,
    readAllProbeReducer,
    readProbeReducer,
    sensorReadAllByTargetReducer,
    sensorReadAllByDomainReducer,
    SensorReadReducer,
    signUpReducer,
    SensorItemReadAllBySensorReducer,
    readAllTargetByProbeReducer,
    readAllTargetByDomainReducer,
    readTargetReducer,
    readNoAuthProbeReducer,
    readMachineReducer,
    readHostReducer,
    CrawlerReadAllByTargetReducer,
    CrawlerAuthInputsReducer,
    MetaSensorItemReadAllReducer,
    MetaSensorItemTypeReadAllReducer,
    readOSReducer,
    readServiceReducer,
    hostReadByProbeReducer,
    noauthAcceptReducer,
    noauthDenyReducer,
    modifyProbeReducer,
    DiscoveryInfraTargetRegistAllReducer,
    HistoryReadAllByProbeReducer,
    HistoryReadAllByProbeAndTypeReducer,
    readAllTargetByInfraReducer,
    InfraReadServiceReducer,
    HistoryTypeReadAllReducer,
    SensorRegistSensorConfigReducer,
    NotificationReadAllUnconfirmedReducer,
  ],
  sagaWatchers: [
    AsyncRequest,
  ],
};


// Configuration
export interface Config {
  container: ContainerConfig;
  rpc: RPCConfig;
  redux: ReduxConfig;
}

const config: Config = {
  container: containerConfig,
  rpc: rpcConfig,
  redux: reduxConfig,
};

export default config;
