import * as React from 'react';
import {
    Container,
    List,
    Header,
} from 'semantic-ui-react';
import Page from '@overflow/commons/api/model/Page';
import Member from '@overflow/member/api/model/Member';
import Notification from '../../api/model/Notification';

export interface StateProps {
    notifications: Page;
}

export interface DispatchProps {
    onReadAllUnconfirmed(member: Member, pageNo: string, countPerPage: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
}

export class NotificationModal extends React.Component<Props, State> {

    private countPerPage: number = 5;
    constructor(props: Props, context: State) {
        super(props, context);
        this.state = {
            list: null,
        };
    }
    public componentWillMount(): void {
        const member = {
            id: 1,
        };
        this.props.onReadAllUnconfirmed(member, String(0), String(this.countPerPage));
    }

    public renderItems(): (JSX.Element | JSX.Element[]) {
        if (this.props.notifications === undefined || this.props.notifications.content.length === 0) {
            return <div>No user notifications found. </div>;
        }
        return this.props.notifications.content.map((item: Notification, index: number) => (
            <List.Item key={index}>
                 <List.Icon name='bell outline' size='large' verticalAlign='middle' />
                <List.Content>
                    <List.Header as='a'>{item.title}</List.Header>
                    <List.Description as='a'>{item.message}</List.Description>
                </List.Content>
            </List.Item>
        ));
    }

    public render(): JSX.Element {

        return (
            <Container fluid>
                <Header as='h4' content='User Notifications' />
                <List divided relaxed>
                    {this.renderItems()}
                </List>
            </Container>
        );
    }
}
